@@ -312,7 +312,7 @@ class SmContext():
                 return service.service_data["always_run_from"]
         return original_runfrom
 
-    def get_service_starter(self, service_name, run_from, proxy, classifier=None, service_mapping_ports=None, port=None, admin_port=None, version=None):
+    def get_service_starter(self, service_name, run_from, proxy, classifier=None, service_mapping_ports=None, port=None, admin_port=None, version=None, append_args=None):
         service = self.get_service(service_name)
         run_from = self.get_run_from_service_override_value_or_use_default(service, run_from)
 
@@ -326,20 +326,21 @@ class SmContext():
             return None
 
         if service_type == "external":
-            starter = SmExternalServiceStarter(self, service_name)
+            starter = SmExternalServiceStarter(self, service_name, append_args)
         elif service_type == "dropwizard":
-            starter = SmDropwizardServiceStarter(self, service_name, run_from, port, admin_port, classifier, service_mapping_ports, version, proxy)
+            starter = SmDropwizardServiceStarter(self, service_name, run_from, port, admin_port, classifier, service_mapping_ports, version, proxy, append_args)
         elif service_type == "play":
-            starter = SmPlayServiceStarter(self, service_name, run_from, port, classifier, service_mapping_ports, version, proxy)
+            starter = SmPlayServiceStarter(self, service_name, run_from, port, classifier, service_mapping_ports, version, proxy, append_args)
         elif service_type == "assets":
-            starter = SmPythonServiceStarter(self, service_name, run_from, port, classifier, service_mapping_ports, version, None)
+            proxy = None
+            starter = SmPythonServiceStarter(self, service_name, run_from, port, classifier, service_mapping_ports, version, proxy, append_args)
         else:
             raise self.exception("Unknown service type '%s' for service '%s' - please check services.json" % (service_type, service_name))
 
         return starter
 
-    def start_service(self, service_name, run_from, proxy, classifier=None, service_mapping_ports=None, port=None, admin_port=None, version=None):
-        service_starter = self.get_service_starter(service_name, run_from, proxy, classifier, service_mapping_ports, port, admin_port, version)
+    def start_service(self, service_name, run_from, proxy, classifier=None, service_mapping_ports=None, port=None, admin_port=None, version=None, appendArgs=None):
+        service_starter = self.get_service_starter(service_name, run_from, proxy, classifier, service_mapping_ports, port, admin_port, version, appendArgs)
         feature_string = pretty_print_list(" with feature$s $list enabled", self.features)
         self.log("Starting '%s' from %s%s..." % (service_name, run_from, feature_string))
         service_process_id = service_starter.start()
